@@ -56,7 +56,7 @@
 #' \describe{
 #'  \item{\option{parallelly.fork.enable}:}{(logical) Enable or disable _forked_ processing.  If `FALSE`, multicore futures becomes sequential futures.  If `NA`, or not set (the default), the a set of best-practices rules decide whether should be supported or not.}
 #'
-#'  \item{\option{parallelly.supportsMulticore.unstable}:}{(character) Controls whether a warning should be produced or not whenever multicore processing is automatically disabled because the environment in which R runs is considered unstable for forked processing, e.g. in the RStudio environment.  If `"warning"` (default), then an informative warning is produces the first time 'multicore' or 'multiprocess' futures are used.  If `"quiet"`, no warning is produced.}
+#'  \item{\option{parallelly.supportsMulticore.unstable}:}{(character) Controls whether a warning should be produced or not whenever multicore processing is automatically disabled because the environment in which R runs is considered unstable for forked processing, e.g. in the RStudio environment.  If `"warn"` (default), then an informative warning is produces the first time 'multicore' or 'multiprocess' futures are used.  If `"quiet"`, no warning is produced.}
 #' }
 #'
 #'
@@ -288,7 +288,7 @@ update_package_options <- function(debug = FALSE) {
 
   update_package_option("fork.enable", mode = "logical", debug = debug)
 
-  update_package_option("supportsMulticore.unstable", mode = "logical", debug = debug)
+  update_package_option("supportsMulticore.unstable", mode = "character", debug = debug)
 
   update_package_option("makeNodePSOCK.setup_strategy", mode = "character", debug = debug)
   update_package_option("makeNodePSOCK.validate", mode = "logical", debug = debug)
