@@ -7,6 +7,10 @@
   ## Set package options based on environment variables
   update_package_options(debug = debug)
 
+  ## If neeeded, work around bug in R preventing us from using the 'parallel'
+  ## setup strategy of PSOCK cluster nodes
+  parallelly_disable_parallel_setup_if_needed()
+
   ## Automatically play nice when 'R CMD check' runs?
   if (isTRUE(as.logical(getEnvVar2("R_PARALLELLY_R_CMD_CHECK_NICE", "TRUE"))) && inRCmdCheck()) {
     if (debug) mdebug("Detected 'R CMD check':\n - adjusting defaults to be a good citizen")
